from django.conf.urls import url
from . import views
from django.contrib.auth import views as auth_views

app_name='nicha'
urlpatterns=[
    url(r'^$', views.index,name='Index'),
    url(r'^faq/$', views.faq,name='FAQ'),
    url(r'^mobile/$', views.mobile,name='Mobile'),
    url(r'^terms/$', views.terms_and_conditions,name='TermsAndConditions'),
    url(r'^privacy/$', views.privacy_policy,name='PrivacyPolicy'),
    url(r'^how-it-works/$', views.how_it_works,name='howItWorks'),
    url(r'^community/$', views.community,name='Community'),
    url(r'^account/$', views.account,name='Account'),
    url(r'^accounts/login/$', views.sign_in_to_account, name='SignInToAnAccount'),
    url(r'^accounts/logout/$',view.sign_out, name='Logout'),
    url(r'^accounts/create/$',view.create_account, name='CreateNewAccount'),
    path('accounts/password-change/',
        auth_views.PasswordChangeView.as_view(template_name='nicha/change_password.html'),
    ),
    path('accounts/password-reset/',
        auth_views.PasswordChangeView.as_view(template_name='nicha/password_reset.html'),
    ),

]



from django.shortcuts import render, redirect
from django.http import HttpResponseRedirect,HttpResponse,Http404
from django.core.urlresolvers import reverse
from django.contrib.auth.models import User
from django.conf import settings
from django.contrib.auth import logout
from django.contrib.auth import authenticate, login


# Create your views here.
# rest full APIS 




#============== index page===================================================
def index(request):
	return render(request,'nicha/index.html',locals())

#============== faq page=====================================================
def faq(request):
	return render(request,'nicha/faq.html',locals())

#============== mobile page==================================================
def mobile(request):
	return render(request,'nicha/mobile.html',locals())


#============== terms and conditions page====================================
def terms_and_conditions(request):
	return render(request,'nicha/terms.html',locals())
#============== privacy policy page==========================================
def privacy_policy(request):
	return render(request,'nicha/privacy.html',locals())
	
#============== how it works page ===========================================
def how_it_works_page(request):
	return render(request,'nicha/how_it_works.html',locals())

#============== community page ==============================================
def community_page(request):
	return render(request,'nicha/community.html',locals())

# # ============= Sign in page ================================================
# def sign_in_page(request):
# 	return render(request,'nicha/sign_in.html',locals())
# #============== Register page ===============================================
# def register_page(request):
# 	return render(request,'nicha/register.html',locals())

# ============= Account =====================================================
def account(request):
	return render(request,'nicha/account.html',locals())

#============== SignIn ======================================================
def sign_in_to_account(request):
	username = request.POST['username']
	password = request.POST['password']
	user = authenticate(request, username=username, password=password)
	if user is not None:
		login(request, user)
	else:
		pass
	return redirect("/")

#============== SignOut =====================================================
def sign_out(request):
	logout(request)
	return redirect("/")

#============= Register =====================================================
def create_account(request):
	username = request.POST['username']
	password = request.POST['password']
	email = request.POST['email']
	user = User.objects.create_user(username,email,password)
	user.save()
	return redirect("/")




from __future__ import unicode_literals

from django.db import models
import uuid

# Create your models here.
# business_status = (('PENDING','PENDING'),('ACTIVE','ACTIVE'))
# branch_status = (('PENDING','PENDING'),('ACTIVE','ACTIVE'))
# social_account_type = (('FACEBOOK','FACEBOOK'),('TWITTER','TWITTER'),('YOUTUBE','YOUTUBE'),('INSTAGRAM','INSTAGRAM'))

# def cover_directory_path(instance,filename):
# 	return 'covers/cover_{0}'.format( filename)

# def logo_directory_path(instance,filename):
# 	return 'logos/logo_{0}'.format( filename)

# class Branch(models.Model):
# 	branch_ref = models.CharField(max_length=100, blank=True, unique=True, default=uuid.uuid4)
# 	business=models.ForeignKey(Business,on_delete=models.CASCADE)
# 	address = models.OneToOneField(Address)
# 	branch_status = models.CharField(blank=True,null=True,choices=business_status,default="PENDING",max_length=20)
# 	cover_1=models.ImageField(null=True,blank=True,upload_to=cover_directory_path) 
# 	cover_2=models.ImageField(null=True,blank=True,upload_to=cover_directory_path)
# 	cover_3=models.ImageField(null=True,blank=True,upload_to=cover_directory_path)
# 	cover_4=models.ImageField(null=True,blank=True,upload_to=cover_directory_path)
# 	cover_5=models.ImageField(null=True,blank=True,upload_to=cover_directory_path)
# 	def __str__(self):
# 		return self.business.name


